@@ -18,7 +18,7 @@ def handle_response(func):
         if isinstance(result, tuple):
             response = result[0]
             code = result[1]
-            use_default_response_message_key = result[2]
+            use_default_response_message_key = result[2] if len(result) > 2 else False
 
         if code not in [200, 201, 204] and use_default_response_message_key:
             response = dict(message=response)
