@@ -102,8 +102,8 @@ class MicroFetcher(object):
         self._prepare_search_list()
         return self
 
-    def global_configs(self, configs):
-        self.global_configs = configs
+    def global_configs(self, **keywords):
+        self.global_configs = keywords
         return self
 
     def feed_list(self, base_data, output_key=None):
